##  Rejecting Discovered Items
You can reject discovered items to focus on systems and services relevant to your enterprise architecture.
To reject discovered items, follow these steps:
  1. From the list, choose the service that needs to be rejected. This opens the side panel.
  2. In the side panel, choose Reject.
